=begin
#Flat API

#The Flat API allows you to easily extend the abilities of the [Flat Platform](https://flat.io), with a wide range of use cases including the following:  * Creating and importing new music scores using MusicXML or MIDI files * Browsing, updating, copying, exporting the user's scores (for example in MP3, WAV or MIDI) * Managing educational resources with Flat for Education: creating & updating the organization accounts, the classes, rosters and assignments.  The Flat API is built on HTTP. Our API is RESTful It has predictable resource URLs. It returns HTTP response codes to indicate errors. It also accepts and returns JSON in the HTTP body. The [schema](/swagger.yaml) of this API follows the [OpenAPI Initiative (OAI) specification](https://www.openapis.org/), you can use and work with [compatible Swagger tools](http://swagger.io/open-source-integrations/). This API features Cross-Origin Resource Sharing (CORS) implemented in compliance with [W3C spec](https://www.w3.org/TR/cors/).  You can use your favorite HTTP/REST library for your programming language to use Flat's API. This specification and reference is [available on Github](https://github.com/FlatIO/api-reference).  Getting Started and learn more:  * [API Overview and interoduction](https://flat.io/developers/docs/api/) * [Authentication (Personal Access Tokens or OAuth2)](https://flat.io/developers/docs/api/authentication.html) * [SDKs](https://flat.io/developers/docs/api/sdks.html) * [Rate Limits](https://flat.io/developers/docs/api/rate-limits.html) * [Changelog](https://flat.io/developers/docs/api/changelog.html) 

OpenAPI spec version: 2.6.0
Contact: developers@flat.io
Generated by: https://github.com/swagger-api/swagger-codegen.git
Swagger Codegen version: 2.4.0-SNAPSHOT

=end

# Common files
require 'flat_api/api_client'
require 'flat_api/api_error'
require 'flat_api/version'
require 'flat_api/configuration'

# Models
require 'flat_api/models/assignment'
require 'flat_api/models/assignment_copy'
require 'flat_api/models/assignment_creation'
require 'flat_api/models/assignment_submission'
require 'flat_api/models/assignment_submission_update'
require 'flat_api/models/class_attachment_creation'
require 'flat_api/models/class_creation'
require 'flat_api/models/class_details'
require 'flat_api/models/class_details_canvas'
require 'flat_api/models/class_details_clever'
require 'flat_api/models/class_details_google_classroom'
require 'flat_api/models/class_details_google_drive'
require 'flat_api/models/class_details_lti'
require 'flat_api/models/class_roles'
require 'flat_api/models/class_state'
require 'flat_api/models/class_update'
require 'flat_api/models/collection'
require 'flat_api/models/collection_capabilities'
require 'flat_api/models/collection_creation'
require 'flat_api/models/collection_modification'
require 'flat_api/models/collection_privacy'
require 'flat_api/models/collection_title'
require 'flat_api/models/collection_type'
require 'flat_api/models/flat_error_response'
require 'flat_api/models/flat_locales'
require 'flat_api/models/google_classroom_coursework'
require 'flat_api/models/google_classroom_submission'
require 'flat_api/models/group'
require 'flat_api/models/group_details'
require 'flat_api/models/group_type'
require 'flat_api/models/license_mode'
require 'flat_api/models/license_sources'
require 'flat_api/models/lms_name'
require 'flat_api/models/lti_credentials'
require 'flat_api/models/lti_credentials_creation'
require 'flat_api/models/media_attachment'
require 'flat_api/models/media_score_sharing_mode'
require 'flat_api/models/organization_invitation'
require 'flat_api/models/organization_invitation_creation'
require 'flat_api/models/organization_roles'
require 'flat_api/models/resource_collaborator_creation'
require 'flat_api/models/resource_rights'
require 'flat_api/models/resource_sharing_key'
require 'flat_api/models/score_comment'
require 'flat_api/models/score_comment_context'
require 'flat_api/models/score_comment_creation'
require 'flat_api/models/score_comment_update'
require 'flat_api/models/score_comments_counts'
require 'flat_api/models/score_creation'
require 'flat_api/models/score_creation_type'
require 'flat_api/models/score_data'
require 'flat_api/models/score_data_encoding'
require 'flat_api/models/score_fork'
require 'flat_api/models/score_license'
require 'flat_api/models/score_likes_counts'
require 'flat_api/models/score_modification'
require 'flat_api/models/score_privacy'
require 'flat_api/models/score_revision'
require 'flat_api/models/score_revision_creation'
require 'flat_api/models/score_revision_statistics'
require 'flat_api/models/score_source'
require 'flat_api/models/score_summary'
require 'flat_api/models/score_track'
require 'flat_api/models/score_track_creation'
require 'flat_api/models/score_track_point'
require 'flat_api/models/score_track_state'
require 'flat_api/models/score_track_type'
require 'flat_api/models/score_track_update'
require 'flat_api/models/score_views_counts'
require 'flat_api/models/user_admin_update'
require 'flat_api/models/user_basics'
require 'flat_api/models/user_creation'
require 'flat_api/models/user_details_admin_license'
require 'flat_api/models/user_instruments'
require 'flat_api/models/resource_collaborator'
require 'flat_api/models/score_details'
require 'flat_api/models/user_public_summary'
require 'flat_api/models/user_details_admin'
require 'flat_api/models/user_public'
require 'flat_api/models/user_details'

# APIs
require 'flat_api/api/account_api'
require 'flat_api/api/class_api'
require 'flat_api/api/collection_api'
require 'flat_api/api/group_api'
require 'flat_api/api/organization_api'
require 'flat_api/api/score_api'
require 'flat_api/api/user_api'

module FlatApi
  class << self
    # Customize default settings for the SDK using block.
    #   FlatApi.configure do |config|
    #     config.username = "xxx"
    #     config.password = "xxx"
    #   end
    # If no block given, return the default Configuration object.
    def configure
      if block_given?
        yield(Configuration.default)
      else
        Configuration.default
      end
    end
  end
end
